@@ -5,14 +5,16 @@ import warnings
 
 import numpy as np
 from scipy.stats import norm
+from deprecate_kwargs import deprecate_kwargs
+from deprecated import deprecated
 
-from ._confint import ConfidenceInterval
+from ._confint import ConfidenceInterval, _SIDE_NAME_MAP, ConfidenceIntervalSides
 from ._utils import add_docstring, remove_parameters_returns_from_docstring
 
 
 __all__ = [
     "compute_difference_confidence_interval",
-    "list_difference_confidence_interval_types",
+    "list_difference_confidence_interval_methods",
 ]
 
 
@@ -20,6 +22,7 @@ __all__ = [
 qnorm = norm.ppf
 
 
+@deprecate_kwargs([["method", "confint_type"]])
 def compute_difference_confidence_interval(
     n_positive: int,
     n_total: int,
@@ -28,6 +31,7 @@ def compute_difference_confidence_interval(
     conf_level: float = 0.95,
     confint_type: str = "wilson",
     clip: bool = True,
+    sides: str = "two-sided",
 ) -> ConfidenceInterval:
     """
     Compute the confidence interval of the difference between two binomial proportions.
@@ -35,19 +39,25 @@ def compute_difference_confidence_interval(
     Parameters
     ----------
     n_positive: int,
-        number of positive samples
+        number of positive samples.
     n_total: int,
-        total number of samples
+        total number of samples.
     ref_positive: int,
-        number of positive samples of the reference
+        number of positive samples of the reference.
     ref_total: int,
-        total number of samples of the reference
+        total number of samples of the reference.
     conf_level: float, default 0.95,
-        confidence level, should be inside the interval (0, 1)
+        confidence level, should be inside the interval (0, 1).
     confint_type: str, default "wilson",
-        type (computation method) of the confidence interval
+        type (computation method) of the confidence interval.
     clip: bool, default True,
-        whether to clip the confidence interval to the interval (-1, 1)
+        whether to clip the confidence interval to the interval (-1, 1).
+    sides: str, default "two-sided",
+        the sides of the confidence interval, should be one of
+        "two-sided" (aliases "2-sided", "two_sided", "2_sided", "ts", "t"),
+        "left-sided" (aliases "left_sided", "left", "ls", "l"),
+        "right-sided" (aliases "right_sided", "right", "rs", "r"),
+        case insensitive.
 
     Returns
     -------
@@ -95,15 +105,38 @@ def compute_difference_confidence_interval(
     if ref_total <= 0:
         raise ValueError(f"ref_total should be positive, but got ref_total={ref_total}")
 
+    if sides.lower() not in _SIDE_NAME_MAP["two-sided"]:
+        raise ValueError(
+            f"sides should be one of {list(_SIDE_NAME_MAP)}, but got {sides}"
+        )
+    else:
+        sides = _SIDE_NAME_MAP[sides.lower()]
+
     confint = _compute_difference_confidence_interval(
-        n_positive, n_total, ref_positive, ref_total, conf_level, confint_type
+        n_positive, n_total, ref_positive, ref_total, conf_level, confint_type, sides
     )
+
     if clip:
         confint.lower_bound = max(confint.lower_bound, -1)
         confint.upper_bound = min(confint.upper_bound, 1)
+
+    if confint.sides == ConfidenceIntervalSides.LeftSided.value:
+        confint.upper_bound = 1
+    elif confint.sides == ConfidenceIntervalSides.RightSided.value:
+        confint.lower_bound = -1
+
     return confint
 
 
+@add_docstring(
+    """
+    NOTE
+    ----
+    the lower bound and upper bound are not adjusted w.r.t. `sides`.
+
+    """,
+    "append",
+)
 @add_docstring(
     remove_parameters_returns_from_docstring(
         compute_difference_confidence_interval.__doc__, parameters="clip"
@@ -116,34 +149,16 @@ def _compute_difference_confidence_interval(
     ref_total: int,
     conf_level: float = 0.95,
     confint_type: str = "wilson",
+    sides: str = "two-sided",
 ) -> ConfidenceInterval:
-    """
-    Compute the confidence interval of the difference between two binomial proportions.
-
-    Parameters
-    ----------
-    n_positive: int,
-        number of positive samples
-    n_total: int,
-        total number of samples
-    ref_positive: int,
-        number of positive samples of the reference
-    ref_total: int,
-        total number of samples of the reference
-    conf_level: float, default 0.95,
-        confidence level, should be inside the interval (0, 1)
-    confint_type: str, default "wilson",
-        type (computation method) of the confidence interval
-
-    Returns
-    -------
-    an instance of `ConfidenceInterval`
-
-    """
+    """ """
 
     warnings.simplefilter(action="ignore", category=RuntimeWarning)
 
-    z = qnorm((1 + conf_level) / 2)
+    if sides != "two-sided":
+        z = qnorm(conf_level)
+    else:
+        z = qnorm((1 + conf_level) / 2)
     n_negative = n_total - n_positive
     ref_negative = ref_total - ref_positive
     ratio = n_positive / n_total
@@ -161,6 +176,7 @@ def _compute_difference_confidence_interval(
         return ConfidenceInterval(
             delta_ratio - np.sqrt((ratio - lower1) ** 2 + (upper2 - ref_ratio) ** 2),
             delta_ratio + np.sqrt((ref_ratio - lower2) ** 2 + (upper1 - ratio) ** 2),
+            delta_ratio,
             conf_level,
             confint_type.lower(),
         )
@@ -182,6 +198,7 @@ def _compute_difference_confidence_interval(
         return ConfidenceInterval(
             delta_ratio - np.sqrt((ratio - lower1) ** 2 + (upper2 - ref_ratio) ** 2),
             delta_ratio + np.sqrt((ref_ratio - lower2) ** 2 + (upper1 - ratio) ** 2),
+            delta_ratio,
             conf_level,
             confint_type.lower(),
         )
@@ -193,12 +210,14 @@ def _compute_difference_confidence_interval(
             return ConfidenceInterval(
                 delta_ratio - item - 0.5 / n_total - 0.5 / ref_total,
                 delta_ratio + item + 0.5 / n_total + 0.5 / ref_total,
+                delta_ratio,
                 conf_level,
                 confint_type.lower(),
             )
         return ConfidenceInterval(
             delta_ratio - item,
             delta_ratio + item,
+            delta_ratio,
             conf_level,
             confint_type.lower(),
         )
@@ -224,7 +243,11 @@ def _compute_difference_confidence_interval(
         )
         theta_star = (delta_ratio + v * (1 - 2 * psi) * z**2) / (1 + u * z**2)
         return ConfidenceInterval(
-            theta_star - w, theta_star + w, conf_level, confint_type.lower()
+            theta_star - w,
+            theta_star + w,
+            delta_ratio,
+            conf_level,
+            confint_type.lower(),
         )
     elif confint_type.lower() in ["mee", "miettinen-nurminen"]:
         theta = ref_total / n_total
@@ -261,7 +284,7 @@ def _compute_difference_confidence_interval(
             elif flag:
                 break
         return ConfidenceInterval(
-            np.min(itv), np.max(itv), conf_level, confint_type.lower()
+            np.min(itv), np.max(itv), delta_ratio, conf_level, confint_type.lower()
         )
     elif confint_type.lower() == "true-profile":
         theta = ref_total / n_total
@@ -292,7 +315,7 @@ def _compute_difference_confidence_interval(
             elif flag:
                 break
         return ConfidenceInterval(
-            np.min(itv), np.max(itv), conf_level, confint_type.lower()
+            np.min(itv), np.max(itv), delta_ratio, conf_level, confint_type.lower()
         )
     elif confint_type.lower() == "hauck-anderson":
         item = 1 / 2 / min(n_total, ref_total) + z * np.sqrt(
@@ -300,7 +323,11 @@ def _compute_difference_confidence_interval(
             + ref_ratio * ref_neg_ratio / (ref_total - 1)
         )
         return ConfidenceInterval(
-            delta_ratio - item, delta_ratio + item, conf_level, confint_type.lower()
+            delta_ratio - item,
+            delta_ratio + item,
+            delta_ratio,
+            conf_level,
+            confint_type.lower(),
         )
     elif confint_type.lower() == "agresti-caffo":
         ratio_1 = (n_positive + 1) / (n_total + 2)
@@ -312,6 +339,7 @@ def _compute_difference_confidence_interval(
         return ConfidenceInterval(
             ratio_1 - ratio_2 - item,
             ratio_1 - ratio_2 + item,
+            delta_ratio,
             conf_level,
             confint_type.lower(),
         )
@@ -324,6 +352,7 @@ def _compute_difference_confidence_interval(
         return ConfidenceInterval(
             ratio_1 - ratio_2 - item,
             ratio_1 - ratio_2 + item,
+            delta_ratio,
             conf_level,
             confint_type.lower(),
         )
@@ -342,7 +371,9 @@ def _compute_difference_confidence_interval(
         ).astuple()
         lower = weight * lower_mn + (1 - weight) * lower_bl
         upper = weight * upper_mn + (1 - weight) * upper_bl
-        return ConfidenceInterval(lower, upper, conf_level, confint_type.lower())
+        return ConfidenceInterval(
+            lower, upper, delta_ratio, conf_level, confint_type.lower()
+        )
     elif confint_type.lower() == "exact":
         raise NotImplementedError
     elif confint_type.lower() == "mid-p":
@@ -392,9 +423,11 @@ _supported_types = [
     # "wang",
     # "pradhan-banerjee",
 ]
+_supported_methods = _supported_types
 
 
 _stochastic_types = []
+_stochastic_methods = _stochastic_types
 
 
 _type_aliases = {
@@ -404,9 +437,19 @@ _type_aliases = {
     "score-cc": "newcombe-cc",
     "brown-li-jeffrey": "brown-li",
 }
+_method_aliases = _type_aliases
 
 
+@deprecated(
+    version="0.0.4", reason="Use `list_difference_confidence_interval_methods` instead."
+)
 def list_difference_confidence_interval_types() -> None:
     """ """
 
     print("\n".join(_supported_types))
+
+
+def list_difference_confidence_interval_methods() -> None:
+    """ """
+
+    print("\n".join(_supported_types))
